@@ -3,6 +3,7 @@ package DBusSession;
 use strict;
 use warnings;
 
+use Carp;
 use File::Which;
 use File::Temp;
 
@@ -30,6 +31,30 @@ sub skip_if_lack_needed_socket_msghdr {
         skip "Failed to load Socket::MsgHdr: $@", $count;
     }
 
+    my $minver = Protocol::DBus::Authn::Mechanism::EXTERNAL->SOCKET_MSGHDR_MINIMUM_VERSION();
+
+    if ( eval { Socket::MsgHdr->VERSION($minver) } ) {
+        diag "Socket::MsgHdr $Socket::MsgHdr::VERSION is new enough.";
+    }
+    else {
+        skip "$@", $count;
+    }
+
+    return;
+}
+
+sub skip_if_missing_or_outdated_mojo {
+    my $count = shift;
+
+    skip 'No Mojo::IOLoop!', $count if !eval { require Mojo::IOLoop };
+    skip 'No Mojo::Promise!', $count if !eval { require Mojo::Promise };
+    skip 'Loop can’t timer()!', $count if !Mojo::IOLoop->can('timer');
+
+    require Mojolicious;
+
+    my $min_ver = 8.15;
+    skip "Mojo is $Mojolicious::VERSION; needs >= $min_ver", $count if !eval { Mojolicious->VERSION($min_ver) };
+
     return;
 }
 
@@ -48,7 +73,7 @@ sub get_bin_or_skip {
 sub new {
     my $class = shift;
 
-    my $dbus_run_session_bin = get_bin() or die "no dbus-run-session!";
+    my $dbus_run_session_bin = get_bin() or confess "no dbus-run-session!";
 
     my $dir = File::Temp::tempdir();
 
